@@ -1,10 +1,21 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+import warnings
+
 import pytest
 
 asdf = pytest.importorskip("asdf")
 
-from asdf.tests.helpers import assert_roundtrip_tree  # noqa: E402
-from numpy.random import randint, random  # noqa: E402
+from asdf.exceptions import AsdfDeprecationWarning
+
+with warnings.catch_warnings():
+    warnings.filterwarnings(
+        "ignore",
+        category=AsdfDeprecationWarning,
+        message=r"asdf.tests.helpers is deprecated.*",
+    )
+    from asdf.tests.helpers import assert_roundtrip_tree
+
+from numpy.random import randint, random
 
 import astropy.coordinates.representation as r  # noqa: E402
 import astropy.units as u  # noqa: E402
